@@ -1,3 +1,5 @@
+mod divider;
+pub use divider::*;
 mod alias;
 pub use alias::*;
 mod brief;
@@ -10,3 +12,5 @@ mod tag;
 pub use tag::*;
 mod r#type;
 pub use r#type::*;
+mod module;
+pub use module::*;
